@@ -5,7 +5,7 @@ from bytez.model import Model
 
 @dataclass
 class CmdStyleTransferModel(Model):
-    def inference(self, image: BinaryIO) -> bytes:
+    def inference(self, image: BinaryIO, api_key: str = "") -> bytes:
         """
         Runs inference on the given image and returns the result as bytes.
 
@@ -26,4 +26,4 @@ class CmdStyleTransferModel(Model):
 
         url = 'https://cmd-styletransfer-tfhmsoxnpq-uc.a.run.app'
 
-        return self._Model__inference(url=url, request_params=request_params)
+        return self._Model__inference(url=url, request_params=request_params, api_key=api_key)
