@@ -6,7 +6,7 @@ from bytez.model import Model
 
 @dataclass
 class FastStyleTransferModel(Model):
-    def inference(self, image: BinaryIO) -> bytes:
+    def inference(self, image: BinaryIO, api_key: str = "") -> bytes:
         """
         Runs inference on the given image and returns the result as bytes.
 
@@ -24,4 +24,4 @@ class FastStyleTransferModel(Model):
 
         url = 'https://fast-style-transfer-tfhmsoxnpq-uc.a.run.app'
 
-        return self._Model__inference(url=url, request_params=request_params)
+        return self._Model__inference(url=url, request_params=request_params, api_key=api_key)
